#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    interface_configuration.py
#       
#    Copyright 2010 Victor Ramirez <virako.9@gmail.com>
#       
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


import gtk
import gobject

import cte
from function import convert_opencv2gtk, load_image_no_webcam
from interface_about import Interface_about


class Interface_configuration():
    """Clase utilizada para las interfaz de configuración. """
    def __init__(self, camera):
        """Inicializador. 
         @param camera: instancia de Camera para trabajar con las cámaras. 
         @type camera: L{Camera}
        """
        # variables
        self.camera = camera
        self.num_cameras = len(self.camera.check_name_cameras())
        self.open_window_configuration = True
        self.configuration_ok = False
        self.refresh = 0
        
        # cargamos el archivo creado con glade
        self.gladefile = "gui/configuration.glade"
        self.glade = gtk.Builder()
        self.glade.add_from_file(self.gladefile)

        #cargamos los widget
        self.window = self.glade.get_object("window_configuration")
        self.image_camera = self.glade.get_object("image_camera")
        
        # modificamos las widget
        self.window.set_title("Configuracion")

        # conectamos las señales
        self.glade.connect_signals(self)
        
        # comprobamos si hay cámaras iniciamos la escala horizontal
        if self.num_cameras != 0:
            self.hscale_camera = self.glade.get_object("hscale_camera")
            self.hscale_camera.set_range(1, self.num_cameras)
            self.hscale_camera.set_increments(1, 1)
            
        else: # si no hay cámaras cargamos la imagen de que no hay cámara
            image = load_image_no_webcam()
            self.load_image(image)
        
        # mostramos la ventana
        self.window.show()

        
    # señales
    def button_aceptar_clicked(self, widget):
        """Callback que es llamado cuando hacemos click en el boton Aceptar, 
         y que guarda todas las variables escritas en la configuracion"""
        
        # terminamos con el refresh
        gobject.source_remove(self.refresh)
        self.refresh = 0
        cte.PLAYER_B = self.glade.get_object("player_b").get_text()
        cte.PLAYER_W = self.glade.get_object("player_w").get_text()
        cte.RANK_B = self.glade.get_object("rank_b").get_text()
        cte.RANK_W = self.glade.get_object("rank_w").get_text()
        cte.SIZE = self.glade.get_object("size").get_text()
        file_sgf = self.glade.get_object("file_sgf").get_filename()
        file_video = self.glade.get_object("file_video").get_filename()
        
        if file_video != None:
            self.values = (file_sgf, file_video)
            self.configuration_ok = True
        elif file_video == None and not self.camera.get_frame():
            self.configuration_ok = False
            print "No hay cámara ni video seleccionado"
        else:
            self.values = (file_sgf,)
            self.num_camera = int(self.hscale_camera.get_value()-1)
            self.configuration_ok = True
        self.window.destroy() # llama a gtk_destroy_window
    
    def button_close_window_clicked(self, widget):
        self.camera.close_camera()
        self.window.destroy()
        
    def hscale_camera_value_changed(self, widget):
        """Callback que se activa cuando movemos la barra de escala, la cual
         nos cambia al numero de cámara que seleccionemos. """
        
        # eliminamos el refresco de cámara
        if self.num_cameras != 1:
            self.camera.close_camera()
            self.num_camera = int(widget.get_value()-1)
            self.camera.open_camera(self.num_camera)
            if self.camera.capture != None:
                self.refresh = gobject.timeout_add(200, self.update)
            else: # cargamos la imagen de que no se encuentra cámara
                image = load_image_no_webcam()
                self.load_image(image)
                self.window.reshow_with_initial_size()
        
    def menu_language_1_activate(self, widget):
        """Callback que es llamado cuando se pulsa el botón del idioma 1 en la 
         barra de menú de la interfaz y que nos cambia al idioma seleccionado. 
         """
        print "cambiado a lenguaje_1"
        
    def menu_language_2_activate(self, widget):
        """Callback que es llamado cuando se pulsa el botón del idioma 2 en la 
         barra de menú de la interfaz y que nos cambia al idioma seleccionado. 
         """
        print "cambiado a lenguaje_2"
        
    def menu_help_about_activate(self, widget):
        """Callback que es llamado cuando se pulsa el botón del idioma 1 en la 
         barra de menú de la interfaz y que nos cambia al idioma seleccionado. 
         """
        Interface_about()
    
    def menu_file_close_activate(self, widget):
        """Callback que es llamado cuando pulsamos la opción de cerrar ventana 
         de la barra menú, la cual cierra la ventana """
        self.camera.close_camera()
        self.window.destroy()
        
    def gtk_destroy_window(self, widget):
        """Callback que es llamado cuando pulsamos la X, pulsamos ALT+F4, o 
         cuando llamamos a window.destroy(), esto no cierra la ventana.  """
        self.open_window_configuration = False
        self.window.destroy()


    # métodos
    def update(self):
        """Función llamada por un bucle cada cierto tiempo que nos actualiza
         la cámara y el video mediante frame y los muesta por pantalla.
         @return: Devuelve True siempre que exista frame de una cámara o 
          un video, y False en caso de no encontrarlo.
         @rtype: C{bool}
         """
        if self.camera.capture == None:
            return False
        frame = self.camera.get_frame()
        self.load_image(frame)
        return True
    
    def load_image(self, image):
        """Nos carga una imagen en la pantalla. 
        @param image: imagen a cargar.
        @type image: L{IplImage}"""
        pix_buf = convert_opencv2gtk(image)
        self.image_camera.set_from_pixbuf(pix_buf)
         
        
    
    
